import { DataLayer } from './data-access';
import { Integration } from './integration';
import { Config, IntegrationApi, IntegrationApiExcutorParams, IntegrationContext, IntegrationEvent, Routes, ZodeSchemaGenerator } from './types';
import { Blueprint } from './workflows/types';
import { NextRequest, NextResponse } from 'next/server';
import { IntegrationMap } from './generated-types';
import { Prisma } from '@prisma-app/client';
import { z, ZodSchema } from 'zod';
export declare class Framework<C extends Config = Config> {
    globalEvents: Map<string, Record<string, IntegrationEvent<any>>>;
    globalEventHandlers: any[];
    globalApis: Map<string, Record<string, IntegrationApi<any>>>;
    integrations: Map<string, Integration>;
    dataLayer: DataLayer;
    config: C;
    static init<C extends Config = Config>(config: C): Framework<C>;
    constructor({ dataLayer, config }: {
        dataLayer: DataLayer;
        config: C;
    });
    connectedIntegrations({ context, }: {
        context: {
            connectionId: string;
        };
    }): Promise<Integration<unknown>[]>;
    get routes(): Record<Routes, string>;
    __registerIntgeration(definition: Integration): void;
    __registerEvents({ events, integrationName, }: {
        events: Record<string, IntegrationEvent<any>>;
        integrationName?: string;
    }): void;
    __registerApis({ apis, integrationName, }: {
        apis: IntegrationApi[];
        integrationName?: string;
    }): void;
    availableIntegrations(): {
        name: string;
        integration: Integration<unknown>;
    }[];
    getIntegration<T extends keyof IntegrationMap>(name: T): IntegrationMap[T];
    getGlobalEvents(): Map<string, Record<string, IntegrationEvent<any>>>;
    getSystemEvents(): Record<string, IntegrationEvent<any>>;
    getEventsByIntegration(name: string): Record<string, IntegrationEvent<any>> | undefined;
    getGlobalEventHandlers(): any[];
    getApis(): Map<string, Record<string, IntegrationApi<any>>>;
    getSystemApis(): Record<string, IntegrationApi<any>> | undefined;
    getApisByIntegration(name: string, includeHidden?: boolean): Record<string, IntegrationApi<any>> | undefined;
    authenticatableIntegrations(): {
        name: string;
        integration: Integration<unknown>;
    }[];
    authenticator(name: string): import("./authenticator").IntegrationAuth;
    connectIntegrationByCredential({ name, connectionId, credential, }: {
        name: string;
        connectionId: string;
        credential: Omit<Prisma.CredentialUncheckedCreateInput, 'k_id'>;
    }): Promise<void>;
    disconnectIntegration({ name, connectionId, }: {
        name: string;
        connectionId: string;
    }): Promise<void>;
    callApi({ integrationName, api, payload, }: {
        integrationName?: string;
        api: string;
        payload: IntegrationApiExcutorParams;
    }): Promise<Record<string, any>>;
    subscribeEvent({ id, interval, timeout, }: {
        id: string;
        interval?: number;
        timeout?: number;
    }): Promise<{
        status: string;
        startedAt: string;
        endedAt: string;
    } | null>;
    triggerEvent<KEY extends keyof C['workflows']['systemEvents'], SYSTEM_EVENT_SCHEMA extends C['workflows']['systemEvents'][KEY]['schema']>({ key, data, user, integrationName, }: {
        integrationName?: string;
        key: KEY;
        data: SYSTEM_EVENT_SCHEMA extends ZodSchema ? z.infer<SYSTEM_EVENT_SCHEMA> : SYSTEM_EVENT_SCHEMA extends ZodeSchemaGenerator ? z.infer<Awaited<ReturnType<SYSTEM_EVENT_SCHEMA>>> : never;
        user?: {
            connectionId: string;
            [key: string]: any;
        };
    }): Promise<{
        event: any;
        workflowEvent?: any;
    }>;
    triggerSystemEvent<T = Record<string, any>>({ key, data, user, }: {
        key: string;
        data: T;
        user?: {
            connectionId: string;
            [key: string]: any;
        };
    }): Promise<import("inngest/types").SendEventOutput<{
        id: string;
    }>>;
    createRouter(): {
        makeWebhookUrl: ({ event, name, }: {
            name: string;
            event: string;
        }) => string;
        makeRedirectURI: () => string;
        makeConnectURI: (props: {
            name: string;
            connectionId: string;
            clientRedirectPath: string;
        }) => string;
        registerRoutes: () => (req: NextRequest) => NextResponse<unknown> | Promise<Response>;
    };
    runBlueprint: ({ blueprint, dataCtx, ctx, }: {
        blueprint: Blueprint;
        dataCtx?: any;
        ctx: IntegrationContext;
    }) => Promise<void>;
}
